from rest_framework.request import Request as _Request


class Request(_Request):

    @property
    def user(self):
        return super(Request, self).user

    @user.setter
    def user(self, value):
        from orm88 import ORM88
        if value.is_authenticated:
            value = ORM88('auth.User').get(id=value.id)
            value.is_authenticated = True
        self._user = value
        self._request.user = value



from rest_framework.views import APIView as _APIView
from .request import Request


class APIView(_APIView):

    def initialize_request(self, request, *args, **kwargs):
        """
       Returns the initial request object.
       """
        parser_context = self.get_parser_context(request)

        return Request(
            request,
            parsers=self.get_parsers(),
            authenticators=self.get_authenticators(),
            negotiator=self.get_content_negotiator(),
            parser_context=parser_context
        )
